@@ -36,12 +36,12 @@ __all__ = [
 	# .gpl
 	'Default', 'Container', 'Numeric', 'DifferenceDict', 
 	'STR', 'IO', 'LST', 'DIC', 'LOG', 'DB', 'IP', 'XL_READ', 'XL_WRITE', 
-	'DictMethods', 'Multi_Execution', 'nslookup'
+	'DictMethods', 'Multi_Execution', 'nslookup',
 	# .convertdict
 	'ConvDict',
 	]
 
-__version__ = "0.0.10"
+__version__ = "0.0.11"
 
 from .juniper import Juniper
 from .jset import JSet
